@@ -248,9 +248,24 @@ NS_DEFINE_STATIC_IID_ACCESSOR(nsAggregatedCycleCollectionParticipant,
 #define NS_INTERFACE_MAP_BEGIN_AGGREGATED(_class)                           \
   NS_IMPL_AGGREGATED_QUERY_HEAD(_class)
 
+#define NS_IMPL_QUERY_CYCLE_COLLECTION(_class)                              \
+  if ( aIID.Equals(NS_GET_IID(nsXPCOMCycleCollectionParticipant)) ) {       \
+    *aInstancePtr = NS_CYCLE_COLLECTION_PARTICIPANT(_class);                \
+    return NS_OK;                                                           \
+  } else
+
 #define NS_INTERFACE_MAP_ENTRY_CYCLE_COLLECTION_AGGREGATED(_class)          \
   NS_IMPL_QUERY_CYCLE_COLLECTION(_class)
 
+#define NS_IMPL_QUERY_CYCLE_COLLECTION_ISUPPORTS(_class)                    \
+  if ( aIID.Equals(NS_GET_IID(nsCycleCollectionISupports)) ) {              \
+    *aInstancePtr = NS_CYCLE_COLLECTION_CLASSNAME(_class)::Upcast(this);    \
+    return NS_OK;                                                           \
+  } else
+
+#define NS_INTERFACE_MAP_ENTRY_CYCLE_COLLECTION_ISUPPORTS(_class)           \
+  NS_IMPL_QUERY_CYCLE_COLLECTION_ISUPPORTS(_class)
+
 #define NS_INTERFACE_MAP_ENTRIES_CYCLE_COLLECTION_AGGREGATED(_class)        \
   NS_INTERFACE_MAP_ENTRY_CYCLE_COLLECTION_AGGREGATED(_class)                \
   NS_INTERFACE_MAP_ENTRY_CYCLE_COLLECTION_ISUPPORTS(_class)
